summaryrefslogtreecommitdiffstats
path: root/src/entryview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/entryview.cpp')
-rw-r--r--src/entryview.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/entryview.cpp b/src/entryview.cpp
index 402eaf5..2965405 100644
--- a/src/entryview.cpp
+++ b/src/entryview.cpp
@@ -260,7 +260,7 @@ void EntryView::setXSLTFile(const TQString& file_) {
void EntryView::slotRefresh() {
setXSLTFile(m_xsltFile);
showEntry(m_entry);
- view()->tqrepaint();
+ view()->repaint();
}
// do some contortions in case the url is relative
@@ -340,10 +340,10 @@ void EntryView::resetColors() {
// this is a rather bad hack to get around the fact that the image cache is not reloaded when
// the gradient files are changed on disk. Setting the URLArgs for write() calls doesn't seem to
// work. So force a reload with a temp file, then catch the completed signal and tqrepaint
TQString s = TQString::fromLatin1("<html><body><img src=\"%1\"><img src=\"%2\"></body></html>")
- .tqarg(dir + TQString::fromLatin1("gradient_bg.png"))
- .tqarg(dir + TQString::fromLatin1("gradient_header.png"));
+ .arg(dir + TQString::fromLatin1("gradient_bg.png"))
+ .arg(dir + TQString::fromLatin1("gradient_header.png"));
delete m_tempFile;
m_tempFile = new KTempFile;
@@ -340,10 +340,10 @@ void EntryView::resetColors() {
// this is a rather bad hack to get around the fact that the image cache is not reloaded when
// the gradient files are changed on disk. Setting the URLArgs for write() calls doesn't seem to
- // work. So force a reload with a temp file, then catch the completed signal and tqrepaint
+ // work. So force a reload with a temp file, then catch the completed signal and repaint
TQString s = TQString::fromLatin1("<html><body><img src=\"%1\"><img src=\"%2\"></body></html>")